@@ -1,10 +1,6 @@
 # -*- coding: utf-8 -*-
 # -*- mode: python -*-
 """ General programming tools """
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 import collections
 import functools
 
